biom.table.Table.add_group_metadata — biom-format.org

# biom-format.org

## biom.table.Table.add_group_metadata

`Table.` `add_group_metadata`(group_md, axis='sample')

  Take a dict of group metadata and add it to an axis

  Parameters: | group_md : dict of tuples group_md should be of the form `{category: (data type, value)` axis : {‘sample’, ‘observation’}, optional The axis to operate on
  Raises: | UnknownAxisError If provided an unrecognized axis.